Enum jwt_simple::claims::Audiences [−][src]
Depending on applications, the audiences property may be either a set or a string.
We support both.
Variants
AsString(String)Implementations
Return true if the audiences include any of the allowed_audiences entries
Get the audiences as a string. If it was originally serialized as a set, it can be only converted to a string if it contains at most one element.