Struct jwt_simple::claims::Claims
source · [−]pub struct Claims;Implementations
sourceimpl Claims
impl Claims
sourcepub fn create(valid_for: Duration) -> JWTClaims<NoCustomClaims>
pub fn create(valid_for: Duration) -> JWTClaims<NoCustomClaims>
Create a new set of claims, without custom data, expiring in valid_for.
sourcepub fn with_custom_claims<CustomClaims: Serialize + DeserializeOwned>(
custom_claims: CustomClaims,
valid_for: Duration
) -> JWTClaims<CustomClaims>
pub fn with_custom_claims<CustomClaims: Serialize + DeserializeOwned>(
custom_claims: CustomClaims,
valid_for: Duration
) -> JWTClaims<CustomClaims>
Create a new set of claims, with custom data, expiring in valid_for.